"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const mariadb_connector_1 = require("./mariadb-connector");
var databaseEngine;
(function (databaseEngine) {
    databaseEngine[databaseEngine["MariaDB"] = 0] = "MariaDB";
})(databaseEngine = exports.databaseEngine || (exports.databaseEngine = {}));
class DatabaseConnectorBuilder {
    constructor(engine) {
        this.engine = engine;
        this.ip = '127.0.0.1';
        this.port = 3306;
        this.database = '';
        this.user = '';
        this.password = '';
    }
    build() {
        switch (this.engine) {
            case databaseEngine.MariaDB:
                return new mariadb_connector_1.MariaDBConnector(this.ip, this.port, this.database, this.user, this.password);
            default:
                throw new Error('Unsupported engine.');
        }
    }
    setHost(ip) {
        this.ip = ip;
        return this;
    }
    setPort(port) {
        this.port = port;
        return this;
    }
    setDatabase(database) {
        this.database = database;
        return this;
    }
    setCredentials(user, password) {
        this.user = user;
        this.password = password;
        return this;
    }
}
exports.DatabaseConnectorBuilder = DatabaseConnectorBuilder;
