"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const yargs_1 = require("./decorators/yargs");
const fs_extra_1 = require("fs-extra");
const analyser_1 = require("./analyser");
const table_1 = require("./table");
const database_connector_builder_1 = require("./database/database-connector-builder");
process.on('uncaughtException', (ex) => {
    console.error(ex);
});
process.on('unhandledRejection', (ex) => {
    console.error(ex);
});
let Main = class Main {
    constructor() {
        this.database = undefined;
        this.host = '127.0.0.1:3306';
        this.user = 'root';
        this.password = 'root';
        this.analysis = false;
        this.reset = false;
    }
    run() {
        return __awaiter(this, void 0, void 0, function* () {
            if (!this.database)
                throw new Error('Please provide a valid database name');
            const [host, port] = this.host.split(':');
            const dbConnectorBuilder = new database_connector_builder_1.DatabaseConnectorBuilder(database_connector_builder_1.databaseEngine.MariaDB);
            const dbConnector = dbConnectorBuilder
                .setHost(host)
                .setPort(parseInt(port, 10))
                .setDatabase(this.database)
                .setCredentials(this.user, this.password)
                .build();
            try {
                if (this.analysis) {
                    let customSchema = analyser_1.dummyCustomSchema;
                    try {
                        customSchema = fs_extra_1.readJSONSync('./custom_schema.json');
                    }
                    catch (ex) {
                        console.warn('Unable to read ./custom_schema.json, this will not take any customization into account.');
                    }
                    const analyser = new analyser_1.Analyser(dbConnector, customSchema);
                    const json = yield analyser.analyse();
                    fs_extra_1.writeJSONSync('./schema.json', json, { spaces: 4 });
                    return;
                }
                ;
                let schema = fs_extra_1.readJSONSync('./schema.json');
                const tableService = new table_1.TableService(dbConnector, schema.maxCharLength || 255, schema.values);
                for (const table of schema.tables) {
                    if (table.lines > 0) {
                        yield tableService.fill(table, this.reset);
                    }
                }
            }
            catch (ex) {
                if (ex.code == 'ENOENT') {
                    console.error('Unable to read from schema.json. Please run with --analyse first.');
                }
                else {
                    console.error(ex);
                }
            }
            finally {
                console.log('Close database connection');
                yield dbConnector.destroy();
            }
        });
    }
};
__decorate([
    yargs_1.Option({ alias: 'db', type: 'string', demandOption: true, description: 'database', })
], Main.prototype, "database", void 0);
__decorate([
    yargs_1.Option({ alias: 'h', type: 'string', })
], Main.prototype, "host", void 0);
__decorate([
    yargs_1.Option({ alias: 'u', type: 'string', demandOption: true, })
], Main.prototype, "user", void 0);
__decorate([
    yargs_1.Option({ alias: 'p', type: 'string', demandOption: true, })
], Main.prototype, "password", void 0);
__decorate([
    yargs_1.Option({ alias: 'a', type: 'boolean', })
], Main.prototype, "analysis", void 0);
__decorate([
    yargs_1.Option({ alias: 'r', type: 'boolean', })
], Main.prototype, "reset", void 0);
Main = __decorate([
    yargs_1.Cli
], Main);
const main = new Main();
(() => __awaiter(void 0, void 0, void 0, function* () {
    yield main.run();
}))();
